@@ -13,6 +13,7 @@
 #define CENTRYDISPLAY_H
 
 //BibleTime includes
+#include "config.h"
 #include "ctextrendering.h"
 #include "cswordmoduleinfo.h"
 #include "cswordbackend.h"
@@ -45,6 +46,17 @@ public:
 	* The displayoptions and filter options are used, too.
 	*/
 	virtual const TQString text( const ListCSwordModuleInfo& modules, const TQString& key, const CSwordBackend::DisplayOptions displayOptions, const CSwordBackend::FilterOptions filterOptions);
+
+#ifdef SWORD_API_1_7
+	/** casts a module to a character pointer and displays it to
+	* raw output (overriden for different display types and
+	* module types if necessary)
+	*
+	* @param imodule module to display
+	* @return error status
+	*/
+	virtual char display(SWModule &imodule) { return 0; };
+#endif
 };
 
 
