@@ -134,7 +134,7 @@ class TQSplitter;
  */
 class BibleTime : public TDEMainWindow, virtual public BibleTimeInterface {
 	friend class CMDIArea;
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	/**
