@@ -94,7 +94,7 @@ void BibleTime::initView() {
 
 	m_mdi = new CMDIArea(m_mainSplitter, "mdiarea" );
 	m_mdi->setMinimumSize(100, 100);
-	m_mdi->setFocusPolicy(TQ_ClickFocus);
+	m_mdi->setFocusPolicy(TQWidget::ClickFocus);
 
 	m_helpMenu = new KHelpMenu(this, TDEGlobal::instance()->aboutData(), true, actionCollection());
 }
