@@ -31,7 +31,7 @@ class CSwordKey;
   * @author The BibleTime Team
   */
 class CMDIArea : public TQWorkspace, public CPointers  {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
