@@ -51,7 +51,7 @@ class TDEActionCollection;
   * @author The BibleTime Team
   */
 class COptionsDialog : public KDialogBase, public CPointers  {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
