@@ -32,7 +32,7 @@ class CTransliterationButton;
   */
 
 class CBibleReadWindow : public CLexiconReadWindow  {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	CBibleReadWindow(ListCSwordModuleInfo modules, CMDIArea* parent, const char *name=0);
