@@ -28,7 +28,7 @@ class TDEPopupMenu;
   * @author The BibleTime team
   */
 // class CTransliterationButton : public TDEToolBarButton  {
-//    Q_OBJECT
+//    TQ_OBJECT
 //    
 // public:
 //  CTransliterationButton(CSwordBackend::FilterOptions* displayOptions, TQWidget *parent, const char *name=0);
@@ -57,7 +57,7 @@ class TDEPopupMenu;
   * @author The BibleTime team
   */
 class CDisplaySettingsButton : public TDEToolBarButton  {
-	Q_OBJECT
+	TQ_OBJECT
 	
 public:
 	CDisplaySettingsButton(CSwordBackend::DisplayOptions *displaySettings, CSwordBackend::FilterOptions *settings, const ListCSwordModuleInfo& useModules, TQWidget *parent=0, const char *name=0);
