@@ -31,7 +31,7 @@ class TDEToolBarPopupAction;
   */
 
 class CLexiconReadWindow : public CReadWindow  {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	CLexiconReadWindow(ListCSwordModuleInfo modules, CMDIArea* parent, const char *name=0);
