@@ -30,7 +30,7 @@
   * @author The BibleTime team
   */
 class CModuleChooserBar : public TDEToolBar  {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	/**
