@@ -32,7 +32,7 @@ class CModuleChooserBar;
   * @author The BibleTime team
   */
 class CModuleChooserButton : public TDEToolBarButton, public CPointers  {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	CModuleChooserButton(CSwordModuleInfo* useModule, CSwordModuleInfo::ModuleType type, const int id, CModuleChooserBar *parent, const char *name = 0 );
