@@ -250,7 +250,7 @@ void CBookKeyChooser::setupCombo(const TQString key, const int depth, const int
 
 /** A keychooser changed. Update and emit a signal if necessary. */
 void CBookKeyChooser::keyChooserChanged(int /*newIndex*/) {
-	const int activeID = boxes[TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))]; //no so good code!
+	const int activeID = boxes[const_cast<TQObject*>(sender())]; //no so good code!
 
 	TQStringList items;
 	CKeyChooserWidget* chooser;
