@@ -44,7 +44,7 @@ namespace sword {
   * @author The BibleTime team
   */
 class CBookTreeChooser : public CKeyChooser  {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	CBookTreeChooser(ListCSwordModuleInfo modules, CSwordKey *key=0, TQWidget *parent=0, const char *name=0);
