@@ -43,15 +43,15 @@ CScrollerWidgetSet::CScrollerWidgetSet(TQWidget *parent, const char *name) : TQW
 
 	btn_up = new TQToolButton( UpArrow, this, "btn_up" );
 	btn_up->setFixedSize(WIDTH, ARROW_HEIGHT);
-	btn_up->setFocusPolicy(TQ_NoFocus);
+	btn_up->setFocusPolicy(TQWidget::NoFocus);
 
 	btn_fx = new CScrollButton( this, "btn_fx" );
 	btn_fx->setFixedSize(WIDTH, MOVER_HEIGHT);
-	btn_fx->setFocusPolicy(TQ_NoFocus);
+	btn_fx->setFocusPolicy(TQWidget::NoFocus);
 
 	btn_down = new TQToolButton( DownArrow, this, "btn_down" );
 	btn_down->setFixedSize(WIDTH, ARROW_HEIGHT);
-	btn_down->setFocusPolicy(TQ_NoFocus);
+	btn_down->setFocusPolicy(TQWidget::NoFocus);
 	m_layout->addWidget( btn_up,0 );
 	m_layout->addWidget( btn_fx,0 );
 	m_layout->addWidget( btn_down,0 );
