@@ -7,6 +7,11 @@
 *
 **********/
 
+// force to use TQt with STL
+#if defined(TQT_NO_STL)
+# define DISABLE_TQT_NO_STL
+# undef TQT_NO_STL
+#endif
 
 
 //BibleTime includes
@@ -1226,3 +1231,8 @@ void CGlossaryFolder::addGroup(const Type type, const TQString& fromLanguage, co
 	}
 }
 
+// restore TQT_NO_STL
+#if defined(DISABLE_TQT_NO_STL)
+# undef DISABLE_TQT_NO_STL
+# define TQT_NO_STL
+#endif
