@@ -35,7 +35,7 @@ class CSearchDialog;
   * @author The BibleTime team
   */
 class CMainIndex : public TDEListView {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	class ToolTip : public TQToolTip {
