@@ -39,7 +39,7 @@ namespace Search {
 	namespace Options {
 	
 class CModuleChooser : public TDEListView, public CPointers {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	class ModuleCheckBoxItem : virtual public TQCheckListItem {
@@ -84,7 +84,7 @@ protected: // Protected methods
 };
 
 class CModuleChooserDialog : public KDialogBase  {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	CModuleChooserDialog(TQWidget* parentDialog, ListCSwordModuleInfo modules);
