@@ -45,7 +45,7 @@ namespace Search {
 	namespace Options {
 	
 class CRangeChooserDialog : public KDialogBase {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	CRangeChooserDialog(TQWidget* parentDialog);
