@@ -413,7 +413,7 @@ const TQString CSearchAnalysisItem::getToolTip() {
 
 CSearchAnalysisView::CSearchAnalysisView(TQCanvas* canvas, TQWidget* parent)
 : TQCanvasView(canvas, parent) {
-	setFocusPolicy(TQ_WheelFocus);
+	setFocusPolicy(TQWidget::WheelFocus);
 	m_toolTip = new ToolTip(this);
 	resize(sizeHint());
 }
