@@ -37,7 +37,7 @@ namespace Search {
 	namespace Result {
 
 class CSearchResultView  : public TDEListView {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	CSearchResultView(TQWidget* parent, const char* name = 0);
